@@ -26,8 +26,8 @@ from google.cloud.recommender_v1beta1.gapic import recommender_client
 
 if sys.version_info[:2] == (2, 7):
     message = (
-        "A future version of this library will drop support for Python 2.7."
-        "More details about Python 2 support for Google Cloud Client Libraries"
+        "A future version of this library will drop support for Python 2.7. "
+        "More details about Python 2 support for Google Cloud Client Libraries "
         "can be found at https://cloud.google.com/python/docs/python2-sunset/"
     )
     warnings.warn(message, DeprecationWarning)
@@ -38,4 +38,8 @@ class RecommenderClient(recommender_client.RecommenderClient):
     enums = enums
 
 
-__all__ = ("enums", "types", "RecommenderClient")
+__all__ = (
+    "enums",
+    "types",
+    "RecommenderClient",
+)
